@@ -40,56 +40,40 @@
 #include <stdint.h>
 
 #include <string>
+#include <vector>
 
 #include "SharedHandle.h"
+#include "DownloadResultCode.h"
 
 namespace aria2 {
 
+class FileEntry;
+
 class DownloadResult
 {
 public:
-  // RESULT is used as an exit status code.
-  enum RESULT {
-    FINISHED = 0,
-    UNKNOWN_ERROR = 1,
-    TIME_OUT = 2,
-    RESOURCE_NOT_FOUND = 3,
-    MAX_FILE_NOT_FOUND = 4,
-    TOO_SLOW_DOWNLOAD_SPEED = 5,
-    NETWORK_PROBLEM = 6,
-    IN_PROGRESS = 7,
-  };
-
   int32_t gid;
  
-  std::string filePath;
+  std::vector<SharedHandle<FileEntry> > fileEntries;
 
-  uint64_t totalLength;
-
-  std::string uri;
-
-  size_t numUri;
+  bool inMemoryDownload;
 
   uint64_t sessionDownloadLength;
 
   // milliseconds
   int64_t sessionTime;
 
-  RESULT result;
+  downloadresultcode::RESULT result;
 
   DownloadResult(int32_t gid,
-		 const std::string& filePath,
-		 uint64_t totalLength,
-		 const std::string& uri,
-		 size_t numUri,
+		 const std::vector<SharedHandle<FileEntry> >& fileEntries,
+		 bool inMemoryDownload,
 		 uint64_t sessionDownloadLength,
 		 int64_t sessionTime,
-		 RESULT result):
+		 downloadresultcode::RESULT result):
     gid(gid),
-    filePath(filePath),
-    totalLength(totalLength),
-    uri(uri),
-    numUri(numUri),
+    fileEntries(fileEntries),
+    inMemoryDownload(inMemoryDownload),
     sessionDownloadLength(sessionDownloadLength),
     sessionTime(sessionTime),
     result(result) {}
