@@ -153,6 +153,15 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_FILE);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new BooleanOptionHandler
+				   (PREF_DISABLE_IPV6,
+				    TEXT_DISABLE_IPV6,
+				    V_FALSE,
+				    OptionHandler::OPT_ARG));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<NumberOptionHandler> op(new NumberOptionHandler
 					 (PREF_DNS_TIMEOUT,
@@ -240,6 +249,16 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_BASIC);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new DefaultOptionHandler
+				   (PREF_INTERFACE,
+				    TEXT_INTERFACE,
+				    NO_DEFAULT_VALUE,
+				    "interface, IP address, hostname",
+				    OptionHandler::REQ_ARG));
+    op->addTag(TAG_ADVANCED);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
 				   (PREF_LOG,
@@ -688,15 +707,6 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
-  {
-    SharedHandle<OptionHandler> op(new ParameterOptionHandler
-				   (PREF_HTTP_AUTH_SCHEME,
-				    TEXT_HTTP_AUTH_SCHEME,
-				    V_BASIC,
-				    V_BASIC));
-    op->addTag(TAG_HTTP);
-    handlers.push_back(op);
-  }
   {
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
 				   (PREF_HTTP_PASSWD,
@@ -969,6 +979,13 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new PrioritizePieceOptionHandler
+				   (PREF_BT_PRIORITIZE_PIECE,
+				    TEXT_BT_PRIORITIZE_PIECE));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<OptionHandler> op(new UnitNumberOptionHandler
 				   (PREF_BT_REQUEST_PEER_SPEED_LIMIT,
