@@ -56,6 +56,8 @@ private:
 
   SharedHandle<OptionHandler>
   getOptionHandlerByName(const std::string& optName);
+
+  static SharedHandle<OptionParser> _optionParser;
 public:
   OptionParser();
 
@@ -63,7 +65,7 @@ public:
 
   // Parses options in argv and writes option name and value to out in
   // NAME=VALUE format. Non-option strings are stored in nonopts.
-  // Throws FatalException when an unrecognized option is found.
+  // Throws Exception when an unrecognized option is found.
   void parseArg(std::ostream& out, std::deque<std::string>& nonopts,
 		int argc, char* const argv[]);
 
@@ -92,6 +94,8 @@ public:
   SharedHandle<OptionHandler> findByShortName(char shortName) const;
 
   const std::deque<SharedHandle<OptionHandler> >& getOptionHandlers() const;
+
+  static SharedHandle<OptionParser> getInstance();
 };
 
 typedef SharedHandle<OptionParser> OptionParserHandle;
