@@ -208,6 +208,15 @@ downloadresultcode::RESULT main(int argc, char* argv[])
     MessageDigestHelper::staticSHA1DigestInit();
 #endif // ENABLE_MESSAGE_DIGEST
 
+    if(op->getAsBool(PREF_DISABLE_IPV6)) {
+      SocketCore::setProtocolFamily(AF_INET);
+    }
+    // Bind interface
+    if(!op->get(PREF_INTERFACE).empty()) {
+      std::string interface = op->get(PREF_INTERFACE);
+      SocketCore::bindAddress(interface);
+    }
+
 #ifdef SIGPIPE
     util::setGlobalSignalHandler(SIGPIPE, SIG_IGN, 0);
 #endif
@@ -250,6 +259,15 @@ downloadresultcode::RESULT main(int argc, char* argv[])
 	  createRequestGroupForUri(requestGroups, op, args);
 	}
 
+    // Remove option values which is only valid for URIs specified in
+    // command-line. If they are left, because op is used as a
+    // template for new RequestGroup(such as created in XML-RPC
+    // command), they causes unintentional effect.
+    op->remove(PREF_OUT);
+    op->remove(PREF_FORCE_SEQUENTIAL);
+    op->remove(PREF_INPUT_FILE);
+    op->remove(PREF_INDEX_OUT);
+    op->remove(PREF_SELECT_FILE);
     if(
 #ifdef ENABLE_XML_RPC
        !op->getAsBool(PREF_ENABLE_XML_RPC) &&
