@@ -3,9 +3,8 @@
 #include <cppunit/extensions/HelperMacros.h>
 
 #include "DHTNode.h"
-#include "DHTUtil.h"
 #include "Exception.h"
-#include "Util.h"
+#include "util.h"
 #include "MockDHTMessageFactory.h"
 #include "MockDHTMessageDispatcher.h"
 #include "MockDHTMessage.h"
@@ -47,11 +46,11 @@ void DHTAnnouncePeerMessageTest::testGetBencodedMessage()
   SharedHandle<DHTNode> remoteNode(new DHTNode());
 
   unsigned char tid[DHT_TRANSACTION_ID_LENGTH];
-  DHTUtil::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
+  util::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
   std::string transactionID(&tid[0], &tid[DHT_TRANSACTION_ID_LENGTH]);
 
   unsigned char infoHash[DHT_ID_LENGTH];
-  DHTUtil::generateRandomData(infoHash, DHT_ID_LENGTH);
+  util::generateRandomData(infoHash, DHT_ID_LENGTH);
 
   std::string token = "token";
   uint16_t port = 6881;
@@ -71,8 +70,8 @@ void DHTAnnouncePeerMessageTest::testGetBencodedMessage()
   aDict["token"] = token;
   dict["a"] = aDict;
 
-  CPPUNIT_ASSERT_EQUAL(Util::urlencode(bencode::encode(dict)),
-		       Util::urlencode(msgbody));
+  CPPUNIT_ASSERT_EQUAL(util::urlencode(bencode::encode(dict)),
+		       util::urlencode(msgbody));
 }
 
 void DHTAnnouncePeerMessageTest::testDoReceivedAction()
@@ -83,11 +82,11 @@ void DHTAnnouncePeerMessageTest::testDoReceivedAction()
   remoteNode->setPort(6881);
 
   unsigned char tid[DHT_TRANSACTION_ID_LENGTH];
-  DHTUtil::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
+  util::generateRandomData(tid, DHT_TRANSACTION_ID_LENGTH);
   std::string transactionID(&tid[0], &tid[DHT_TRANSACTION_ID_LENGTH]);
 
   unsigned char infoHash[DHT_ID_LENGTH];
-  DHTUtil::generateRandomData(infoHash, DHT_ID_LENGTH);
+  util::generateRandomData(infoHash, DHT_ID_LENGTH);
 
   std::string token = "token";
   uint16_t port = 6882;
